@@ -31,6 +31,7 @@
 
 #include "esp_ota_ops.h"
 
+#include "esp_http_client.h"
 #include "esp_http_server.h"
 
 #include "nvs.h"
@@ -81,18 +82,22 @@
 #include "pthread.h"
 #include "esp_pthread.h"
 
+#ifdef CONFIG_ESP32S2_ULP_COPROC_ENABLED
 #ifdef CONFIG_IDF_TARGET_ESP32
 #include "esp32/ulp.h"
 #endif
 
 #ifdef CONFIG_IDF_TARGET_ESP32S2
 #include "esp32s2/ulp.h"
+#ifdef CONFIG_ESP32S2_ULP_COPROC_RISCV
 #include "esp32s2/ulp_riscv.h"
 #endif
+#endif
 
 #ifdef CONFIG_IDF_TARGET_ESP32S3
 #include "esp32s3/ulp.h"
 #endif
+#endif
 
 #ifndef CONFIG_IDF_TARGET_ESP32S2 // No BT in ESP32-S2
 
